pub enum AvatarImageSafetySetting {
None,
MediaPreviews,
InviteAvatars,
}Expand description
The safety setting to watch to decide whether the image of the avatar should be displayed.
Variants
None
No setting needs to be watched, the image is always shown when available.
MediaPreviews
The media previews safety setting should be watched, with the image only shown when allowed.
This setting also requires the Room where the avatar is presented.
InviteAvatars
The invite avatars safety setting should be watched, with the image only shown when allowed.
This setting also requires the Room where the avatar is presented.
Implementations
Sourceimpl AvatarImageSafetySetting
impl AvatarImageSafetySetting
Sourcefn register_enum() -> Type
fn register_enum() -> Type
Registers the enum only once.